@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,7 @@ package org.drools.workbench.screens.guided.dtable.client.widget.table.model.syn
 
 import java.util.Collections;
 import java.util.List;
+
 import javax.enterprise.context.Dependent;
 
 import org.drools.workbench.models.guided.dtable.shared.model.ActionCol52;
@@ -26,7 +27,7 @@ import org.drools.workbench.models.guided.dtable.shared.model.BaseColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.BaseColumnFieldDiff;
 import org.drools.workbench.models.guided.dtable.shared.model.BaseColumnFieldDiffImpl;
 import org.drools.workbench.models.guided.dtable.shared.model.LimitedEntryCol;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoException;
 
 @Dependent
 public class ActionRetractFactColumnSynchronizer extends ActionColumnSynchronizer {
@@ -37,12 +38,12 @@ public class ActionRetractFactColumnSynchronizer extends ActionColumnSynchronize
     }
 
     @Override
-    public boolean handlesAppend(final MetaData metaData) throws ModelSynchronizer.MoveColumnVetoException {
+    public boolean handlesAppend(final MetaData metaData) throws VetoException {
         return handlesUpdate(metaData);
     }
 
     @Override
-    public void append(final ColumnMetaData metaData) throws ModelSynchronizer.MoveColumnVetoException {
+    public void append(final ColumnMetaData metaData) throws VetoException {
         if (!handlesAppend(metaData)) {
             return;
         }
@@ -53,7 +54,7 @@ public class ActionRetractFactColumnSynchronizer extends ActionColumnSynchronize
     }
 
     @Override
-    public boolean handlesUpdate(final MetaData metaData) throws ModelSynchronizer.MoveColumnVetoException {
+    public boolean handlesUpdate(final MetaData metaData) throws VetoException {
         if (!(metaData instanceof ColumnMetaData)) {
             return false;
         }
@@ -62,7 +63,7 @@ public class ActionRetractFactColumnSynchronizer extends ActionColumnSynchronize
 
     @Override
     public List<BaseColumnFieldDiff> update(final ColumnMetaData originalMetaData,
-                                            final ColumnMetaData editedMetaData) throws ModelSynchronizer.MoveColumnVetoException {
+                                            final ColumnMetaData editedMetaData) throws VetoException {
         //Check operation is supported
         if (!(handlesUpdate(originalMetaData) && handlesUpdate(editedMetaData))) {
             return Collections.emptyList();
@@ -107,7 +108,7 @@ public class ActionRetractFactColumnSynchronizer extends ActionColumnSynchronize
     }
 
     @Override
-    public boolean handlesMoveColumnsTo(final List<? extends MetaData> metaData) throws ModelSynchronizer.MoveColumnVetoException {
+    public boolean handlesMoveColumnsTo(final List<? extends MetaData> metaData) throws VetoException {
         for (MetaData md : metaData) {
             if (!(md instanceof MoveColumnToMetaData)) {
                 return false;
