@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -24,8 +24,6 @@ import com.google.gwt.junit.GWTMockUtilities;
 import com.google.gwt.user.client.ui.SimplePanel;
 import com.google.gwt.user.client.ui.Widget;
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.drools.workbench.models.datamodel.oracle.FieldAccessorsAndMutators;
-import org.drools.workbench.models.datamodel.oracle.ModelField;
 import org.drools.workbench.models.datamodel.rule.BaseSingleFieldConstraint;
 import org.drools.workbench.models.guided.dtable.shared.model.ConditionCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
@@ -33,13 +31,16 @@ import org.drools.workbench.screens.guided.dtable.client.resources.i18n.GuidedDe
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableView;
 import org.drools.workbench.screens.guided.dtable.client.wizard.column.plugins.ConditionColumnPlugin;
 import org.drools.workbench.screens.guided.dtable.client.wizard.column.plugins.commons.PatternWrapper;
-import org.drools.workbench.services.verifier.api.client.index.DataType;
+import org.gwtbootstrap3.client.ui.TextBox;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.BeforeClass;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.kie.soup.project.datamodel.oracle.DataType;
+import org.kie.soup.project.datamodel.oracle.FieldAccessorsAndMutators;
+import org.kie.soup.project.datamodel.oracle.ModelField;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
@@ -49,9 +50,19 @@ import org.uberfire.client.callbacks.Callback;
 import org.uberfire.ext.widgets.core.client.wizards.WizardPageStatusChangeEvent;
 import org.uberfire.mocks.EventSourceMock;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
 import static org.drools.workbench.screens.guided.rule.client.util.ModelFieldUtil.modelField;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class FieldPageTest {
@@ -87,7 +98,7 @@ public class FieldPageTest {
     private CalculationTypePage calculationTypePage;
 
     @Mock
-    private FieldPage fieldPage;
+    private FieldPage<ConditionColumnPlugin> fieldPage;
 
     @Mock
     private OperatorPage operatorPage;
@@ -96,7 +107,7 @@ public class FieldPageTest {
     private AdditionalInfoPage<ConditionColumnPlugin> additionalInfoPage;
 
     @Mock
-    private ValueOptionsPage valueOptionsPage;
+    private ValueOptionsPage<ConditionColumnPlugin> valueOptionsPage;
 
     @Mock
     private TranslationService translationService;
@@ -311,29 +322,54 @@ public class FieldPageTest {
 
     @Test
     public void testIsCompleteWhenFactFieldIsNull() throws Exception {
+
+        when(plugin.isFieldBindingValid()).thenReturn(true);
         when(plugin.constraintValue()).thenReturn(BaseSingleFieldConstraint.TYPE_LITERAL);
         when(plugin.getFactField()).thenReturn(null);
 
         page.isComplete(Assert::assertFalse);
-        verify(view).showSelectFieldWarning();
+
+        verify(page).fieldBindingWarningToggle(true);
+        verify(page).factFieldWarningToggle(false);
+    }
+
+    @Test
+    public void testIsCompleteWhenBindingIsNotValid() throws Exception {
+
+        when(plugin.isFieldBindingValid()).thenReturn(false);
+        when(plugin.constraintValue()).thenReturn(BaseSingleFieldConstraint.TYPE_LITERAL);
+        when(plugin.getFactField()).thenReturn("factField");
+
+        page.isComplete(Assert::assertFalse);
+
+        verify(page).fieldBindingWarningToggle(false);
+        verify(page).factFieldWarningToggle(true);
     }
 
     @Test
     public void testIsCompleteWhenFactFieldIsNotNull() throws Exception {
+
+        when(plugin.isFieldBindingValid()).thenReturn(true);
         when(plugin.constraintValue()).thenReturn(BaseSingleFieldConstraint.TYPE_LITERAL);
         when(plugin.getFactField()).thenReturn("factField");
 
         page.isComplete(Assert::assertTrue);
-        verify(view).hideSelectFieldWarning();
+
+        verify(page).fieldBindingWarningToggle(true);
+        verify(page).factFieldWarningToggle(true);
     }
 
     @Test
     public void testIsCompleteWhenConstraintValueIsPredicate() throws Exception {
+
+        when(plugin.isFieldBindingValid()).thenReturn(true);
         when(plugin.constraintValue()).thenReturn(BaseSingleFieldConstraint.TYPE_PREDICATE);
         when(plugin.getFactField()).thenReturn(null);
 
         page.isComplete(Assert::assertTrue);
-        verify(view).hideSelectFieldWarning();
+
+        verify(page).fieldBindingWarningToggle(true);
+        verify(page).factFieldWarningToggle(true);
     }
 
     @Test
@@ -363,6 +399,10 @@ public class FieldPageTest {
         page.prepareView();
 
         verify(view).init(page);
+        verify(page).setupPatternWarningMessages();
+        verify(page).setupPredicateBindingInfoBox();
+        verify(page).setupBinding();
+        verify(page).setupField();
     }
 
     @Test
@@ -374,22 +414,183 @@ public class FieldPageTest {
     }
 
     @Test
-    public void testSetupField() {
+    public void testSetupFieldWhenConstraintValueIsNotPredicate() {
         final String factField = "factField";
 
+        doReturn(false).when(page).isConstraintValuePredicate();
         doReturn(factField).when(page).getFactField();
 
-        doNothing().when(page).forEachFactField(this.consumer.capture());
+        doNothing().when(page).forEachFactField(consumer.capture());
 
         page.setupField();
 
-        final Consumer<String> consumer = this.consumer.getValue();
+        consumer.getValue().accept(factField);
 
-        consumer.accept(factField);
-
-        verify(view).addItem(factField,
-                             factField);
-        verify(view).setupFieldList();
+        verify(view).enableListFieldView();
+        verify(view).addItem(factField, factField);
+        verify(view).setupEmptyFieldList();
         verify(view).selectField(factField);
     }
+
+    @Test
+    public void testSetupFieldWhenConstraintValueIsPredicate() {
+
+        final String factField = "factField";
+
+        doReturn(true).when(page).isConstraintValuePredicate();
+        doReturn(factField).when(page).getFactField();
+
+        page.setupField();
+
+        view.enablePredicateFieldView();
+        view.setField(factField);
+    }
+
+    @Test
+    public void testSetupFieldWhenConstraintValueIsFormula() {
+        final String factField = "age";
+        doReturn(oracle).when(presenter).getDataModelOracle();
+        doReturn(BaseSingleFieldConstraint.TYPE_RET_VALUE).when(plugin).constraintValue();
+        doReturn(new PatternWrapper("Person", "p")).when(plugin).patternWrapper();
+        doReturn(factField).when(page).getFactField();
+
+        page.setupField();
+
+        verify(view).enableListFieldView();
+        verify(view).setupEmptyFieldList();
+        verify(page).forEachFactField(any(Consumer.class));
+        verify(view).selectField(factField);
+        verify(view, never()).enablePredicateFieldView();
+    }
+
+    @Test
+    public void testSetupPatternWarningMessagesWhenFactTypeIsNotNil() {
+
+        final String factType = "factType";
+
+        doReturn(factType).when(page).factType();
+
+        page.setupPatternWarningMessages();
+
+        verify(view).patternWarningToggle(false);
+    }
+
+    @Test
+    public void testSetupPatternWarningMessagesWhenFactTypeIsNil() {
+
+        final String factType = "";
+
+        doReturn(factType).when(page).factType();
+
+        page.setupPatternWarningMessages();
+
+        verify(view).patternWarningToggle(true);
+    }
+
+    @Test
+    public void testFactFieldWarningToggleWhenFactFieldIsValid() {
+
+        final boolean isFactFieldValid = true;
+
+        page.factFieldWarningToggle(isFactFieldValid);
+
+        verify(view, never()).showSelectFieldWarning();
+        verify(view).hideSelectFieldWarning();
+    }
+
+    @Test
+    public void testFactFieldWarningToggleWhenFactFieldIsNotValid() {
+
+        final boolean isFactFieldValid = false;
+
+        page.factFieldWarningToggle(isFactFieldValid);
+
+        verify(view).showSelectFieldWarning();
+        verify(view, never()).hideSelectFieldWarning();
+    }
+
+    @Test
+    public void testFieldBindingWarningToggleWhenFieldBindingIsValid() {
+
+        final boolean isFieldBindingValid = true;
+
+        page.fieldBindingWarningToggle(isFieldBindingValid);
+
+        verify(view, never()).showFieldBindingWarning();
+        verify(view).hideFieldBindingWarning();
+    }
+
+    @Test
+    public void testFieldBindingWarningToggleWhenFieldBindingIsNotValid() {
+
+        final boolean isFieldBindingValid = false;
+
+        page.fieldBindingWarningToggle(isFieldBindingValid);
+
+        verify(view).showFieldBindingWarning();
+        verify(view, never()).hideFieldBindingWarning();
+    }
+
+    @Test
+    public void testSetupPredicateBindingInfoBoxWhenConstraintValueIsPredicate() {
+
+        doReturn(BaseSingleFieldConstraint.TYPE_PREDICATE).when(plugin).constraintValue();
+
+        page.setupPredicateBindingInfoBox();
+
+        verify(view).showPredicateBindingInfo();
+        verify(view, never()).hidePredicateBindingInfo();
+    }
+
+    @Test
+    public void testSetupPredicateBindingInfoBoxWhenConstraintValueIsNotPredicate() {
+
+        doReturn(BaseSingleFieldConstraint.TYPE_LITERAL).when(plugin).constraintValue();
+
+        page.setupPredicateBindingInfoBox();
+
+        verify(view).hidePredicateBindingInfo();
+        verify(view, never()).showPredicateBindingInfo();
+    }
+
+    @Test
+    public void testSetupPredicateBindingInfoBoxWhenConstraintValueIsFormula() {
+
+        doReturn(BaseSingleFieldConstraint.TYPE_RET_VALUE).when(plugin).constraintValue();
+
+        page.setupPredicateBindingInfoBox();
+
+        verify(view).hidePredicateBindingInfo();
+        verify(view, never()).showPredicateBindingInfo();
+    }
+
+    @Test
+    public void testSetupBindingWhenItIsBindable() {
+
+        final TextBox textBox = mock(TextBox.class);
+        final boolean isBindable = true;
+
+        doReturn(isBindable).when(plugin).isBindable();
+        doReturn(textBox).when(page).newBindingTextBox();
+
+        page.setupBinding();
+
+        verify(view).setupBinding(textBox);
+        verify(view).bindingToggle(isBindable);
+    }
+
+    @Test
+    public void testSetupBindingWhenItIsNotBindable() {
+
+        final TextBox textBox = mock(TextBox.class);
+        final boolean isBindable = false;
+
+        doReturn(isBindable).when(plugin).isBindable();
+        doReturn(textBox).when(page).newBindingTextBox();
+
+        page.setupBinding();
+
+        verify(view, never()).setupBinding(textBox);
+        verify(view).bindingToggle(isBindable);
+    }
 }
