@@ -25,16 +25,21 @@ import javax.inject.Inject;
 
 import com.google.gwt.user.client.ui.IsWidget;
 import elemental2.promise.Promise;
+import org.drools.scenariosimulation.api.model.AbstractScesimData;
+import org.drools.scenariosimulation.api.model.AbstractScesimModel;
 import org.drools.scenariosimulation.api.model.AuditLog;
+import org.drools.scenariosimulation.api.model.Background;
 import org.drools.scenariosimulation.api.model.ScenarioSimulationModel;
 import org.drools.scenariosimulation.api.model.ScenarioWithIndex;
+import org.drools.scenariosimulation.api.model.ScesimModelDescriptor;
+import org.drools.scenariosimulation.api.model.Settings;
 import org.drools.scenariosimulation.api.model.Simulation;
-import org.drools.scenariosimulation.api.model.SimulationDescriptor;
 import org.drools.workbench.screens.scenariosimulation.businesscentral.client.editor.strategies.BusinessCentralDMNDataManagementStrategy;
 import org.drools.workbench.screens.scenariosimulation.businesscentral.client.editor.strategies.BusinessCentralDMODataManagementStrategy;
 import org.drools.workbench.screens.scenariosimulation.client.editor.ScenarioSimulationEditorPresenter;
 import org.drools.workbench.screens.scenariosimulation.client.editor.ScenarioSimulationEditorWrapper;
 import org.drools.workbench.screens.scenariosimulation.client.editor.strategies.DataManagementStrategy;
+import org.drools.workbench.screens.scenariosimulation.client.enums.GridWidget;
 import org.drools.workbench.screens.scenariosimulation.client.handlers.ScenarioSimulationHasBusyIndicatorDefaultErrorCallback;
 import org.drools.workbench.screens.scenariosimulation.client.resources.i18n.ScenarioSimulationEditorConstants;
 import org.drools.workbench.screens.scenariosimulation.client.rightpanel.TestToolsPresenter;
@@ -48,11 +53,13 @@ import org.drools.workbench.screens.scenariosimulation.service.RunnerReportServi
 import org.drools.workbench.screens.scenariosimulation.service.ScenarioSimulationService;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
+import org.gwtbootstrap3.client.ui.TabListItem;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.ErrorCallback;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracleFactory;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
+import org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants;
 import org.kie.workbench.common.widgets.configresource.client.widget.bound.ImportsWidgetPresenter;
 import org.kie.workbench.common.widgets.metadata.client.KieEditor;
 import org.uberfire.backend.vfs.ObservablePath;
@@ -63,6 +70,7 @@ import org.uberfire.client.annotations.WorkbenchPartTitle;
 import org.uberfire.client.annotations.WorkbenchPartTitleDecoration;
 import org.uberfire.client.annotations.WorkbenchPartView;
 import org.uberfire.client.mvp.PlaceManager;
+import org.uberfire.client.views.pfly.multipage.MultiPageEditorViewImpl;
 import org.uberfire.client.views.pfly.multipage.PageImpl;
 import org.uberfire.ext.editor.commons.service.support.SupportsCopy;
 import org.uberfire.ext.editor.commons.service.support.SupportsDelete;
@@ -181,16 +189,16 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
     }
 
     @Override
-    public void onImport(String fileContents, RemoteCallback<Simulation> importCallBack, ErrorCallback<Object> importErrorCallback, Simulation simulation) {
+    public void onImport(String fileContents, RemoteCallback<AbstractScesimModel> importCallBack, ErrorCallback<Object> importErrorCallback, AbstractScesimModel<? extends AbstractScesimData> scesimModel) {
         importExportService.call(importCallBack,
                                  importErrorCallback)
-                .importSimulation(CSV, fileContents, simulation);
+                .importScesimModel(CSV, fileContents, scesimModel);
     }
 
     @Override
-    public void onExportToCsv(RemoteCallback<Object> exportCallBack, ScenarioSimulationHasBusyIndicatorDefaultErrorCallback scenarioSimulationHasBusyIndicatorDefaultErrorCallback, Simulation simulation) {
+    public void onExportToCsv(RemoteCallback<Object> exportCallBack, ScenarioSimulationHasBusyIndicatorDefaultErrorCallback scenarioSimulationHasBusyIndicatorDefaultErrorCallback, AbstractScesimModel<? extends AbstractScesimData> scesimModel) {
         importExportService.call(exportCallBack, scenarioSimulationHasBusyIndicatorDefaultErrorCallback)
-                .exportSimulation(CSV, simulation);
+                .exportScesimModel(CSV, scesimModel);
     }
 
     @Override
@@ -207,11 +215,13 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
     }
 
     @Override
-    public void onRunScenario(RemoteCallback<SimulationRunResult> refreshModelCallback, ScenarioSimulationHasBusyIndicatorDefaultErrorCallback scenarioSimulationHasBusyIndicatorDefaultErrorCallback, SimulationDescriptor simulationDescriptor, List<ScenarioWithIndex> toRun) {
+    public void onRunScenario(RemoteCallback<SimulationRunResult> refreshModelCallback, ScenarioSimulationHasBusyIndicatorDefaultErrorCallback scenarioSimulationHasBusyIndicatorDefaultErrorCallback, ScesimModelDescriptor simulationDescriptor, Settings settings, List<ScenarioWithIndex> toRun, Background background) {
         service.call(refreshModelCallback, scenarioSimulationHasBusyIndicatorDefaultErrorCallback)
                 .runScenario(versionRecordManager.getCurrentPath(),
                              simulationDescriptor,
-                             toRun);
+                             toRun,
+                             settings,
+                             background);
     }
 
     @Override
@@ -230,12 +240,78 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
     }
 
     @Override
-    public void validate(Simulation simulation, RemoteCallback<?> callback) {
+    public void validate(Simulation simulation, Settings settings, RemoteCallback<?> callback) {
         scenarioSimulationEditorPresenter.getView().showLoading();
         service.call(
                 callback,
                 scenarioSimulationEditorPresenter.getValidationFailedCallback())
-                .validate(simulation, versionRecordManager.getCurrentPath());
+                .validate(simulation, settings, versionRecordManager.getCurrentPath());
+    }
+
+    /**
+     * This method is called when the main grid tab (Model) is focused
+     */
+    @Override
+    public void onEditTabSelected() {
+        super.onEditTabSelected();
+        scenarioSimulationEditorPresenter.onEditTabSelected();
+    }
+
+    @Override
+    public void onOverviewSelected() {
+        super.onOverviewSelected();
+        scenarioSimulationEditorPresenter.onOverviewSelected();
+    }
+
+    /**
+     * This method adds specifically the Background grid and its related onFocus behavior
+     * @param scenarioGridWidget
+     */
+    @Override
+    public void addBackgroundPage(final ScenarioGridWidget scenarioGridWidget) {
+        final MultiPageEditorViewImpl editorMultiPageView = (MultiPageEditorViewImpl) kieView.getMultiPage().getView();
+        final String mainPageTitle = CommonConstants.INSTANCE.EditTabTitle();
+        final String backgroundPageTitle = ScenarioSimulationEditorConstants.INSTANCE.backgroundTabTitle();
+        final int mainPageIndex = editorMultiPageView.getPageIndex(mainPageTitle);
+        final int backgroundPageIndex = mainPageIndex + 1;
+        kieView.getMultiPage().addPage(backgroundPageIndex, new PageImpl(scenarioGridWidget, backgroundPageTitle) {
+            @Override
+            public void onFocus() {
+                super.onFocus();
+                onBackgroundTabSelected();
+            }
+        });
+    }
+
+    @Override
+    protected void addImportsTab(IsWidget importsWidget) {
+        kieView.getMultiPage().addPage(new PageImpl(importsWidget, CommonConstants.INSTANCE.DataObjectsTabTitle()) {
+            @Override
+            public void onFocus() {
+                super.onFocus();
+                onImportsTabSelected();
+            }
+        });
+    }
+
+    @Override
+    public void selectSimulationTab() {
+        final MultiPageEditorViewImpl editorMultiPageView = (MultiPageEditorViewImpl) kieView.getMultiPage().getView();
+        final int pageIndex = editorMultiPageView.getPageIndex(CommonConstants.INSTANCE.EditTabTitle());
+        final TabListItem item = (TabListItem) editorMultiPageView.getTabBar().getWidget(pageIndex);
+        if (item != null) {
+            item.showTab(false);
+        }
+    }
+
+    @Override
+    public void selectBackgroundTab() {
+        final MultiPageEditorViewImpl editorMultiPageView = (MultiPageEditorViewImpl) kieView.getMultiPage().getView();
+        final int pageIndex = editorMultiPageView.getPageIndex(ScenarioSimulationEditorConstants.INSTANCE.backgroundTabTitle());
+        final TabListItem item = (TabListItem) editorMultiPageView.getTabBar().getWidget(pageIndex);
+        if (item != null) {
+            item.showTab(false);
+        }
     }
 
     protected void registerTestToolsCallback() {
@@ -276,12 +352,13 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
 
     @Override
     protected Supplier<ScenarioSimulationModel> getContentSupplier() {
-        return scenarioSimulationEditorPresenter.getContentSupplier();
+        return () -> scenarioSimulationEditorPresenter.getModel();
     }
 
     @Override
     protected void save(final String commitMessage) {
-        synchronizeColumnsDimension();
+        synchronizeColumnsDimension(scenarioSimulationEditorPresenter.getContext().getScenarioGridPanelByGridWidget(GridWidget.SIMULATION),
+                                    scenarioSimulationEditorPresenter.getContext().getScenarioGridPanelByGridWidget(GridWidget.BACKGROUND));
         final ScenarioSimulationModel model = scenarioSimulationEditorPresenter.getModel();
         RemoteCallback<Path> saveSuccessCallback = getSaveSuccessCallback(scenarioSimulationEditorPresenter.getJsonModel(model).hashCode());
         service.call(saveSuccessCallback,
@@ -293,11 +370,8 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
 
     @Override
     protected Command getBeforeSaveAndRenameCommand() {
-        return this::synchronizeColumnsDimension;
-    }
-
-    protected void synchronizeColumnsDimension() {
-        scenarioSimulationEditorPresenter.getFocusedContext().getScenarioGridPanel().synchronizeFactMappingsWidths();
+        return () -> synchronizeColumnsDimension(scenarioSimulationEditorPresenter.getContext().getScenarioGridPanelByGridWidget(GridWidget.SIMULATION),
+                                                 scenarioSimulationEditorPresenter.getContext().getScenarioGridPanelByGridWidget(GridWidget.BACKGROUND));
     }
 
     @Override
@@ -345,7 +419,7 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
         scenarioSimulationEditorPresenter.setPackageName(content.getDataModel().getPackageName());
         resetEditorPages(content.getOverview());
         DataManagementStrategy dataManagementStrategy;
-        if (ScenarioSimulationModel.Type.RULE.equals(content.getModel().getSimulation().getSimulationDescriptor().getType())) {
+        if (ScenarioSimulationModel.Type.RULE.equals(content.getModel().getSettings().getType())) {
             dataManagementStrategy = new BusinessCentralDMODataManagementStrategy(oracleFactory);
         } else {
             dataManagementStrategy = new BusinessCentralDMNDataManagementStrategy(dmnTypeService, scenarioSimulationEditorPresenter.getEventBus());
@@ -363,50 +437,12 @@ public class ScenarioSimulationEditorBusinessCentralWrapper extends KieEditor<Sc
         scenarioSimulationEditorPresenter.getModelSuccessCallbackMethod(dataManagementStrategy, model);
     }
 
-    /**
-     * This method is called when the main grid tab (Model) is focused
-     */
-    @Override
-    public void onEditTabSelected() {
-        super.onEditTabSelected();
-        ScenarioGridWidget scenarioGridWidget = scenarioSimulationEditorPresenter.getView().getScenarioGridWidget();
-        scenarioSimulationEditorPresenter.setFocusedContext(scenarioGridWidget.getScenarioSimulationContext());
-        scenarioSimulationEditorPresenter.setItemMenuForMainGridEnabled(true);
-        scenarioGridWidget.clearSelections();
-        scenarioGridWidget.select();
-        scenarioSimulationEditorPresenter.getBackgroundGridWidget().deselect();
+    protected void onBackgroundTabSelected() {
+        scenarioSimulationEditorPresenter.onBackgroundTabSelected();
     }
 
-    @Override
-    public void onOverviewSelected() {
-        super.onOverviewSelected();
-        scenarioSimulationEditorPresenter.setFocusedContext(
-                scenarioSimulationEditorPresenter.getView().getScenarioGridWidget().getScenarioSimulationContext());
-        scenarioSimulationEditorPresenter.setItemMenuForMainGridEnabled(true);
-    }
-
-    /**
-     * This method adds specifically the Background grid and its related onFocus behavior
-     * @param scenarioGridWidget
-     */
-    @Override
-    public void addBackgroundPage(final ScenarioGridWidget scenarioGridWidget) {
-        addPage(new PageImpl(scenarioGridWidget, ScenarioSimulationEditorConstants.INSTANCE.backgroundTabTitle()) {
-            @Override
-            public void onFocus() {
-                super.onFocus();
-                enableBackgroundTab();
-            }
-        });
-    }
-
-    protected void enableBackgroundTab() {
-        ScenarioGridWidget backgroundWidget = scenarioSimulationEditorPresenter.getBackgroundGridWidget();
-        scenarioSimulationEditorPresenter.setFocusedContext(backgroundWidget.getScenarioSimulationContext());
-        scenarioSimulationEditorPresenter.setItemMenuForMainGridEnabled(false);
-        backgroundWidget.clearSelections();
-        backgroundWidget.select();
-        scenarioSimulationEditorPresenter.getView().getScenarioGridWidget().deselect();
+    protected void onImportsTabSelected() {
+        scenarioSimulationEditorPresenter.onImportsTabSelected();
     }
 
     private RemoteCallback<ScenarioSimulationModelContent> getModelSuccessCallback() {
